﻿var utils = require('./utils.js');

module.exports.parseDependencies = function parseDependencies(dependencyArray, logger) {
    if (!dependencyArray || !dependencyArray.length) {
        logger.warn("Dependencies array is empty");
        return [];
    }

    var parsedArray = [];
    dependencyArray.forEach(function (depStr) {
        depStr = depStr.trim();
        var deps = depStr.split(';');
        deps.forEach(function (d) {
            d = d.trim();
            if (d.indexOf('@') == -1) {
                parsedArray.push({buildSessionId: d});
                return;
            }
            var threeParts = d.split('@'); //Must contain exactly 3 parts - appname, branch and build
            if (threeParts.length != 3)
                throw 'Invalid dependency: ' + d;

            var appName = threeParts[0].trim();
            var branch = threeParts[1].trim();
            var build = threeParts[2].trim();
            if (!appName.length)
                throw 'Missing appName: ' + d;
            if (!branch.length)
                throw 'Missing branch: ' + d;
            if (!build.length)
                throw 'Missing build: ' + d;

            parsedArray.push({appName: appName, build: build, branch: branch});
        });
    });
    return parsedArray;
}

module.exports.parseDependenciesFile = function parseDependenciesFile(filename, logger) {
    var parsedJson = utils.readJsonSync(filename);
    if (!parsedJson || !Array.isArray(parsedJson)) {
        throw 'Invalid file structure (not a JSON document)';
    }
    var parsedDependencies = [];
    parsedJson.forEach(function (depItem) {
        if (depItem.appName && depItem.build && depItem.branch) {
            parsedDependencies.push({
                appName: depItem.appName.toString(),
                branch: depItem.branch.toString(),
                build: depItem.build.toString()
            });
        } else if (depItem.buildSessionId) {
            parsedDependencies.push({
                buildSessionId: depItem.buildSessionId.toString(),
            });
        } else {
            throw 'Invalid dependency item: ' + JSON.stringify(depItem);
        }
    });
    return parsedDependencies;
}